#
# spec file for package zutty
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zutty
Version:        0.16
Release:        1.4
Summary:        Terminal program with GLES renderer and low latency
License:        GPL-3.0-or-later
Group:          System/X11/Terminals
URL:            https://tomscii.sig7.se/zutty/
#Git-Clone:     https://git.hq.sig7.se/zutty.git
# from https://git.hq.sig7.se/zutty.git/snapshot/0.16.tar.gz
Source:         zutty-0.16.tar.gz
Source1:        zutty-0.16.tar.gz.asc
Source3:        FAQ.md
# Note: Tumbleweed contains waf, but Leap does not (yet), so we use python3 and add waf to the sources.
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  libXmu-devel
BuildRequires:  pkgconfig
BuildRequires:  python3

%description
An X terminal emulator rendering through OpenGL ES shaders.
It has good input latency and VTxxx emulation over most other
terminals, ranging second after xterm (as of 2022).
It uses FreeType, but does not support fontconfig, thus won't find
fonts by their usual names. (See FAQ for details.)

%prep
%autosetup -n %{name}-%{version}-a578956
cp -a "%{_sourcedir}/FAQ.md" .

%build
CXXFLAGS="%{?optflags}" LDFLAGS="%{?build_ldflags}" ./waf configure --prefix="%{_prefix}" --no-werror
./waf
strip build/src/zutty

%install
./waf install --destdir=%{buildroot}

%files
%{_bindir}/zutty
%doc FAQ.md
%license LICENSE

%changelog
* Mon Jun 24 2024 Bart Verhagen <bart@verhagenconsultancy.be> - 0.16
- Update to 0.16:
  * Update documentation
  * Add resource options bellIsAudible & bellIsUrgent)
  * Use FreeType underline metrics when rendering a scaled font
  * Some light GLSL refactoring
  * Place shader code into separate source files
  * GPU performance optimization: use RGBA8 format instead of RGBA32F
  * Cut measured latency by zeroing the EGL swap interval
  * Significantly improve/correct rasterization of scaled fonts
  * Add XTQMODKEYS (partial, only for supporting modifyOtherKeys)
  * Implement DECSCUSR (w/o blinking): block, bar & underline cursors)
  * Repository migration
  * Add NetBSD-specific font search path
  * Fix regression in last commit
  * Preserve RGB color across SGR attribute settings
  * Remove deprecated key from desktop entry file
  * Fix clearing glyph area before rendering overlay font glyph
* Mon Jan 29 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 0.15:
  * Implement DECSCUSR (w/o blinking): block, bar & underline cursors
  * Add XTQMODKEYS (partial, only for supporting modifyOtherKeys)
* Mon Mar 20 2023 Avindra Goolcharan <avindra@opensuse.org>
- Update to 0.14:
  * Update repo urls (846c013)
  * Correct modifyOtherKeys=2 behaviour for certain Shift-modified keys (5331995)
  * Upgrade WAF to version 2.0.25 (8db89ee)
  * Add mouse protocol encoding for buttons 6-7 (wheel left/right) and 8-11 (310d913)
  * Ignore several more esoteric keysyms (db2f40a)
  * Ignore, but do not prematurely cancel sequence on bad parameter value (bc6e089)
- lint spec with spec-cleaner
* Sun Nov  6 2022 Jan Engelhardt <jengelh@inai.de>
- Update description with the good and bad characteristics.
- Add FAQ document from the project wiki.
* Tue Oct 25 2022 Bart Verhagen <barrie.verhagen@gmail.com> - 0.13
- Packaged zutty terminal emulator version 0.13
- Add support for openSUSE Tumbleweed
- Add support for openSUSE Leap 15.2 - 15.4
